<?php

namespace App\Controllers;

use App\Models\UserModel;
use App\Models\BlogModel;
use App\Models\CategoryModel;

class Admin extends BaseController
{
    // dashbord
    public function index()
    {
        $session = session();

        if ($session->get("logged_in")) {

            $categoryModel = new CategoryModel();
            $categories = $categoryModel->findAll();

            $blogModel = new BlogModel();
            $blogs = $blogModel->findAll();

            return view("admin/dashboard", [
                "categories" => count($categories),
                "blogs" => count($blogs)
            ]);
        } else {
            return redirect()->to(site_url("login"));
        }
    }

    // admin controller methods
    public function login()
    {
        $session = session();

        if ($session->get("logged_in")) {

            return redirect()->to(site_url("dashboard"));
        } else {
            if ($this->request->getMethod() == "post") {
                // form submission code
                $rules = [
                    "email" => "required|valid_email",
                    "password" => "required|min_length[6]|validateUser[email, password]"
                ];

                $messages = [
                    "email" => [
                        "valid_email" => "Invalid Email address"
                    ],
                    "password" => [
                        "validateUser" => "Invalid credentials"
                    ]
                ];

                if (!$this->validate($rules, $messages)) {

                    return view("admin/login", [
                        "validation" => $this->validator
                    ]);
                } else {

                    // logged in successfully
                    $userModel = new UserModel();

                    $userdata = $userModel->where("email", $this->request->getVar("email"))->first();

                    $session->set($userdata);
                    $session->set("logged_in", 1);

                    return redirect()->to(site_url('dashboard'));
                }
            }

            return view("admin/login");
        }
    }

    public function register()
    {
        $session = session();

        if ($session->get("logged_in")) {

            return redirect()->to(site_url("dashboard"));
        } else {
            if ($this->request->getMethod() == "post") {
                // form submission code
                $rules = [
                    "name" => "required",
                    "email" => "required|valid_email|is_unique[users.email]",
                    "password" => "required|min_length[6]",
                    "confirm_password" => "required|matches[password]"
                ];

                $messages = [
                    "name" => [
                        "required" => "Name field is required"
                    ],
                    "email" => [
                        "required" => "Email field is required",
                        "is_unique" => "Email address should be unique"
                    ],
                    "password" => [
                        "required" => "Password field is required",
                        "min_length" => "Password min length equal to 6"
                    ],
                    "confirm_password" => [
                        "required" => "Confirm Password field is required",
                        "matches" => "Password didn't match"
                    ]
                ];

                if (!$this->validate($rules, $messages)) {
                    // return to view with errors
                    return view("admin/register", [
                        "validation" => $this->validator
                    ]);
                } else {

                    // save data to database
                    $userModel = new UserModel();
                    //print_r($this->request->getVar());die;
                    $data = [
                        "name" => $this->request->getVar("name"),
                        "email" => $this->request->getVar("email"),
                        //"password" => password_hash($this->request->getVar("password"), PASSWORD_DEFAULT)
                        "password" => $this->request->getVar("password")
                    ];

                    $userModel->save($data);

                    $session = session();

                    $session->setFlashdata("success", "User Registered Successfully");

                    return redirect()->to(site_url("login"));
                }
            }

            return view("admin/register");
        }
    }

    public function logout(){
        $session = session();
        $session->destroy();
        return redirect()->to(site_url("/login"));
    }
}
