<?php

namespace App\Controllers;

use App\Models\CategoryModel;
use App\Models\BlogModel;

class Blog extends BaseController
{
    private $db;
    private $builder;

    public function __construct()
    {
        $this->db = \Config\Database::connect();
    }
    // blog controller methods
    public function createBlog()
    {
        $categoryModel = new CategoryModel();
        $categories = $categoryModel->where("status", 1)->findAll();

        if ($this->request->getMethod() == "post") {

            $rules = [
                "category_id" => "required",
                "name" => "required"
            ];

            $messages = [
                "category_id" => [
                    "required" => "Please select category"
                ],
                "name" => [
                    "required" => "Name field is required"
                ]
            ];

            if (!$this->validate($rules, $messages)) {

                // this function wil create blog and save to database
                return view("blog/create-blog", [
                    "categories" => $categories,
                    "validation" => $this->validator
                ]);
            } else {

                $session = session();

                // form posted without any error
                $blogModel = new BlogModel();

                $fileObject = $this->request->getFile("image");

                $filename = $fileObject->getClientName();

                if(empty($filename)){
                    $session->setFlashdata("error", "Please upload an image");
                    return redirect()->to(site_url('create-blog'));
                }

                $fileObject->move("images", $filename);

                $filePath = "/images/" . $filename;

                $blog_data = [
                    "category_id" => $this->request->getVar("category_id"),
                    "name" => $this->request->getVar("name"),
                    "image" => $filePath,
                    "description" => $this->request->getVar("description"),
                    "status" => $this->request->getVar("status")
                ];

                $blogModel->save($blog_data);

                $session = session();
                $session->setFlashdata("success", "Blog saved successfully");
                return redirect()->to(site_url('create-blog'));
            }
        }

        // this function wil create blog and save to database
        return view("blog/create-blog", [
            "categories" => $categories
        ]);
    }

    public function listBlog()
    {
        $this->builder = $this->db->table("blogs");
        $this->builder->select("blogs.*, cat.name as category_name");
        $this->builder->join("categories as cat", "cat.id = blogs.category_id");
        $data = $this->builder->get()->getResultArray();
        //echo $this->db->getLastQuery();
        // this function will list all blogs
        return view("blog/list-blog", [
            "blogs" => $data
        ]);
    }

    public function deleteBlog($blog_id = null){

        $blogModel = new BlogModel();

        $blogModel->delete($blog_id);

        $session = session();

        $session->setFlashdata("success", "Blog has been deleted successfully");

        return redirect()->to(site_url("list-blog"));
    }
}
