<?php

namespace App\Controllers;

use App\Models\CategoryModel;

class Category extends BaseController
{
    // category controller methods
    public function createCategory()
    {
        if ($this->request->getMethod() == "post") {

            $rules = [
                "name" => "required|is_unique[categories.name]"
            ];

            $messages = [
                "name" => [
                    "required" => "Category name required",
                    "is_unique" => "Category name should be unique"
                ]
            ];

            if (!$this->validate($rules, $messages)) {
                return view("category/create-category", [
                    "validation" => $this->validator
                ]);
            } else {

                $categoryModel = new CategoryModel();

                $data = [
                    "name" => $this->request->getVar("name"),
                    "status" => $this->request->getVar("status")
                ];

                $categoryModel->save($data);

                $session = session();

                $session->setFlashdata("success", "Category created successfully");

                return redirect()->to(site_url("create-category"));
            }
        }
        return view("category/create-category");
    }

    public function listCategory()
    {
        $categoryModel = new CategoryModel();

        $categories = $categoryModel->orderBy("id", "desc")->findAll();
        // this is method to list all categories
        return view("category/list-category", [
            "categories" => $categories
        ]);
    }

    public function deleteCategory($category_id = null)
    {
        $categoryModel = new CategoryModel();

        $categoryModel->delete($category_id);

        $session = session();

        $session->setFlashdata("success", "Category deleted successfully");

        return redirect()->to(site_url('list-category'));
    }
}
